@@ -958,9 +958,9 @@ def spectral_separation_routine(
                 separated_flux_A.size = flux_templateA[buffer_mask].size. Same for the returned wavelength.
                 This can be disabled by setting return_unbuffered=False in the options object.
     """
-    if rv_options.fitting_routine == 'RotBF':
+    if rv_options.fitting_profile == 'RotBF':
         from rotational_broadening_function_fitting import get_fit_parameter_values
-    elif rv_options.fitting_routine == 'Gaussian':
+    elif rv_options.fitting_profile == 'Gaussian':
         from gaussian_fitting import get_fit_parameter_values
     else:
         raise ValueError('Unrecognised fitting routine.')
